#include <p18cxxx.h>
#include "usb\usb.h"

// Configuration Bits
#pragma config PLLDIV 	= 5					// 20 MHz
#pragma config CPUDIV 	= OSC1_PLL2			// 12 MIPS
#pragma config USBDIV 	= 2					// USB FS (48 MHz)
#pragma config FOSC 	= HSPLL_HS			// High Speed Clock PLL Enabled

#pragma config FCMEN 	= OFF				// Fail Safe Clock Monitor Disabled
#pragma config IESO 	= OFF				// Int/Ext Switchover Disabled
#pragma config PWRT 	= ON				// Power Up Timer Enabled

#pragma config BOR 		= OFF				// No Brownout Reset
#pragma config BORV 	= 0					//

#pragma config VREGEN 	= ON				// USB Internal Voltage Generator Enabled

#pragma config WDT 		= OFF				// Watchdog Disabled
#pragma config WDTPS 	= 32768				// Watchdog Period

#pragma config MCLRE 	= OFF				// MCLR Input Enabled

#pragma config LPT1OSC 	= OFF				// Timer 1 in High Power Mode

#pragma config PBADEN 	= OFF				// Port B Digital
#pragma config CCP2MX 	= ON				// CCP2 on Port C

#pragma config STVREN 	= ON				// Stack Overflow/Underflow Reset
#pragma config LVP 		= OFF				// Low Voltage ICSP Disabled
#pragma config XINST 	= OFF				// Standard Instruction Set
#pragma config DEBUG 	= OFF				// No Debug

#pragma config CP0 		= OFF				// Code Protection Disabled
#pragma config CP1 		= OFF
#pragma config CP2 		= OFF
#pragma config CP3 		= OFF
#pragma config CPB 		= OFF
#pragma config CPD 		= OFF

#pragma config WRT0 	= OFF				// Write Protection Disabled
#pragma config WRT1 	= OFF
#pragma config WRT2 	= OFF
#pragma config WRT3 	= OFF
#pragma config WRTB 	= ON                // Write Code Protect Boot Block
#pragma config WRTC 	= OFF
#pragma config WRTD 	= OFF

#pragma config EBTR0 	= OFF				// Table Read Protection Disabled
#pragma config EBTR1 	= OFF
#pragma config EBTR2 	= OFF
#pragma config EBTR3 	= OFF
#pragma config EBTRB 	= OFF

#define RM_RESET_VECTOR            0x000800 // define relocated vector addresses
#define RM_HIGH_INTERRUPT_VECTOR   0x000808
#define RM_LOW_INTERRUPT_VECTOR    0x000818

/** VECTOR MAPPING *******************************************/
#pragma code _HIGH_INTERRUPT_VECTOR = 0x000008
void _high_ISR (void)
{
    _asm goto RM_HIGH_INTERRUPT_VECTOR _endasm
}

#pragma code _LOW_INTERRUPT_VECTOR = 0x000018
void _low_ISR (void)
{
    _asm goto RM_LOW_INTERRUPT_VECTOR _endasm
}

/** BOOT LOADER CODE ******************************************/
#pragma code

/*
 * Name         : main
 *
 * Synopsis     : void main(void)
 *
 * Description  : 
 * 
 */
void main(void)
{
    USB_SM_Init();
    
    while (1)
    {
        USB_SM_Run();
        PIR2bits.USBIF = 0;
    }
}

#pragma code user = RM_RESET_VECTOR     // This address defined as 0x800 above
                                        // or can be defined in header file
/** END OF BOOT LOADER ****************************************/
