#include "usb\usbdsc.h"
#include "usb\types.h"

/*
 * Device Descriptor
 */
rom unsigned char DeviceDescriptor[] =
{
    18,             // bLength
    DEVICE,         // bDescriptorType
    0x00, 0x02,     // bcdUSB
    0,              // bDeviceClass
    0,              // bDeviceSubclass
    0,              // bDeviceProtocol
    8,              // bMaxPacketSize
    0xCD, 0xAB,     // idVendor (Test Values)
    0x34, 0x12,     // idProduct (Test Values)
    0x78, 0x56,     // bcdDevice (Test Values)
    1,              // iManufacturer
    2,              // iProduct
    3,              // iSerialNumber
    1               // bNumConfigurations
};

/*
 * Configuration Descriptor
 */
rom unsigned char ConfigDescriptor[] =
{
    /* Standard Configuration Descriptor */
    9,              // bLength
    CONFIGURATION,  // bDescriptorType
    0x29, 0x00,     // wTotalLength (41 bytes)
    1,              // bNumInterfaces
    1,              // bConfigurationValue,
    0,              // iConfiguration
    0x80,           // bmAttributes
    50,             // bMaxPower = (50*2) mA

    /* Standard Interface Descriptor */
    9,              // bLength
    INTERFACE,      // bDescriptorType
    0,              // bInterfaceNumber
    0,              // bAlternateSetting
    2,              // bNumEndpoints
    HID_INTF_CLASS, // bInterfaceClass
    0,              // bInterfaceSubclass
    0,              // bInterfaceProtocol
    0,              // iInterface

    /* HID Interface Descriptor */
    9,              // bLength
    HID_DSC_CLASS,  // bDescriptorType
    0x11, 0x01,     // bcdHID
    0,              // bCountryCode
    1,              // bNumDescriptors
    HID_DSC_REPORT, // bDescriptorType
    0x1D, 0x00,     // wDescriptorLength = 29 bytes

    /* Standard Endpoint Descriptor */
    7,              // bLength
    ENDPOINT,       // bDescriptorType
    0x81,           // bEndpointAddress (1 IN)
    0x03,           // bmAttributes (Interrupt Endpoint)
    0x40, 0x00,     // wMaxPacketSize (64 bytes)
    10,             // bInterval (10 ms)

    7,              // bLength
    ENDPOINT,       // bDescriptorType
    0x01,           // bEndpointAddress (1 OUT)
    0x03,           // bmAttributes (Interrupt Endpoint)
    0x40, 0x00,     // wMaxPacketSize (64 bytes)
    10              // bInterval (10 ms)
};

/*
 * String Descriptors
 */
rom unsigned char LangID[] =
{
    4,              // bLength
    STRING,         // bDescriptorType
    0x09, 0x04      // wLangID (US English)
};

rom unsigned char Manufacturer[] = // Home Appliances Inc. (Test Values)
{
    42,             // bLength
    STRING,         // bDescriptorType
    'H','\0', 'o','\0', 'm','\0', 'e','\0', ' ','\0',
    'A','\0', 'p','\0', 'p','\0', 'l','\0', 'i','\0', 'a','\0', 'n','\0', 'c','\0', 'e','\0', 's','\0', ' ','\0',
    'I','\0', 'n','\0', 'c','\0', '.','\0'
};

rom unsigned char Product[] = // Bootloader (Test Values)
{
    22,             // bLength
    STRING,         // bDescriptorType
    'B','\0', 'o','\0', 'o','\0', 't','\0', 'l','\0', 'o','\0', 'a','\0', 'd','\0', 'e','\0', 'r','\0'
};

rom unsigned char SerialNumber[] = // Revision 1.0 (Test Values)
{
    26,             // bLength
    STRING,         // bDescriptorType
    'R','\0', 'e','\0', 'v','\0', 'i','\0', 's','\0', 'i','\0', 'o','\0', 'n','\0', ' ','\0', '1','\0', '.', '\0', '0', '\0'
};

rom unsigned char* rom StringList[] =
{
    &LangID[0],
    &Manufacturer[0],
    &Product[0],
    &SerialNumber[0]
};

rom unsigned char HidReportDsc[] =
{
    0x06, 0x00, 0xFF,       //  Usage Page (Vendor Defined)
    0x09, 0x01,             //  Usage (Vendor Usage)
    
    0xA1, 0x01,             //  Collection (Application)
        0x19, 0x01,         //      Usage Minimum (Vendor Usage = 1)
        0x29, 0x40,         //      Usage Maximum (Vendor Usage = 64)
        0x15, 0x00,         //      Logical Minimum (Vendor Usage = 0)
        0x26, 0xFF, 0x00,   //      Logical Maximum (Vendor Usage = 255)
        0x75, 0x08,         //      Report Size (Vendor Usage = 8)
        0x95, 0x40,         //      Report Count (Vendor Usage = 64)
        0x81, 0x02,         //      Input (Data, Var, Abs)
        0x19, 0x01,         //      Usage Minimum (Vendor Usage = 1)
        0x29, 0x40,         //      Usage Maximum (Vendor Usage = 64)
        0x91, 0x02,         //      Output (Data, Var, Ads)
    0xC0                    // End of Collection
};
